OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Onbekende leertipe",
    "Invalid image" : "Ongeldige prent",
    "today" : "vandag",
    "seconds ago" : "sekondes gelede",
    "For the best results, please consider using a GNU/Linux server instead." : "Oorweeg die gebruik van 'n GNU/Linux bediener vir die beste resultate.",
    "Apps" : "Toepassings",
    "Help" : "Hulp",
    "Personal" : "Persoonlik",
    "Users" : "Gebruikers",
    "Admin" : "Admin",
    "web services under your control" : "webdienste onder jou beheer"
},
"nplurals=2; plural=(n != 1);");
